###POlicy area-level analysis. General policy categories. Yearly time periods.

##1. Effect of legislative volume on interest groups
library(ggplot2)
library(car)

finaldataG<-read.table('./intermediate data/finaldataGyear')
lexpolG<-read.table('./intermediate data/lexpolGyear')


results<-matrix(NA, 15,9)

x<-1:NROW(lexpolG)

for (i in x) {
  results[i,1]<-as.character(lexpolG[i,1])
  
  temp1<-t(as.vector(finaldataG[i,])) #IGs
  temp2<-t(as.vector(lexpolG[i,])) #laws
  interest.groups<-as.numeric(temp1[2:29])
  laws<-as.numeric(temp2[2:29])
  
  interest.groupsL1<-c(NA, interest.groups[1:27])
  lawsL1<-c(NA, laws[1:27])
  
  #ccf(interest.groups,laws, type="correlation",na.action=na.contiguous, main=as.character(lexpolG[i,25]))
  
  t2<-lm(interest.groups~interest.groupsL1+lawsL1)
  
  results[i,2]<-round(t2$coefficients[2], digits=3)  		#coef iGL1
  
  results[i,5]<-round(t2$coefficients[3], digits=3)			#coef LAWSL1
  
  results[i,3]<-round(coef(summary(t2))[,'Std. Error'][2], digits=3)	#st.errror IGL1
  
  results[i,6]<-round(coef(summary(t2))[,'Std. Error'][3], digits=3)	#st.error LAWSL1
  
  results[i,4]<-round(anova(t2)[1,5], digits=2)				#p-value IGL1
  
  results[i,7]<-round(anova(t2)[2,5], digits=2)				#p-value LAWSL1
  
  results[i,8]<-round(sum(interest.groups, na.rm=T),digits=0)	#sumIG
  
  results[i,9]<-sum(laws, na.rm=T)				#sumLAWS
  
}


results<-as.data.frame(results)
colnames(results)<-c('policy.area.','INTG.L1','st.error','p-v','LAWS.L1','st.error2','p-v2','mean.INTG','sum.LAWS')

###Write the table of results
write.csv(results, './results/year/lawsONintgroupsGENERAL.csv')


###Prepare the dotplots
results$policy.area<-recode(results$policy.area., "'03'='Agriculture';'04'='Fisheries';'05'='Social policy';'07'='Transport';'09'='Taxation';'11'='External';'12'='Energy';'13'='Industry';'14'='Regional policy';'15'='Environment';'16'='Sci,edu,culture';'17'='Economic law';'18'='CFSP';'19'='Justice';'10'='EMU'")

results$LAWS.L1<-as.numeric(as.character(results$LAWS.L1))
results$se2<-as.numeric(as.character(results$st.error2))
results$lower<-results$LAWS.L1-results$se2*1.96
results$upper<-results$LAWS.L1+results$se2*1.96


results$policy.area <- reorder(results$policy.area, results$LAWS.L1)


plot1 <- ggplot(results, aes(LAWS.L1, policy.area)) + geom_point(size = 3.5) + ylab("")+xlab('Regression coefficient and 95% confidence intervals for the effect of the\n(lagged) volume of new legislation on the number of newly registered interest groups')

plot2<-plot1 + geom_vline(aes(xintercept = 0), linetype = 2) + geom_segment(aes(x=lower, xend=upper, yend=policy.area))

png(file="./results/year/lawsONintgroupsGENERAL2.png",width=620,height=540)
plot2
dev.off()


##2. Effect of interest groups on legislative volume

results<-matrix(NA, 15,9)

x<-1:NROW(lexpolG)

for (i in x) {
  results[i,1]<-as.character(lexpolG[i,1])
  
  temp1<-t(as.vector(finaldataG[i,])) #IGs
  temp2<-t(as.vector(lexpolG[i,])) #laws
  interest.groups<-as.numeric(temp1[2:29])
  laws<-as.numeric(temp2[2:29])
  
  interest.groupsL1<-c(NA, interest.groups[1:27])
  lawsL1<-c(NA, laws[1:27])
  
  #ccf(interest.groups,laws, type="correlation",na.action=na.contiguous, main=as.character(lexpolG[i,25]))
  
  t2<-lm(laws~interest.groupsL1+lawsL1)
  
  results[i,2]<-round(t2$coefficients[2], digits=3)			#coef iGL1
  
  results[i,5]<-round(t2$coefficients[3], digits=3)			#coef LAWSL1
  
  results[i,3]<-round(coef(summary(t2))[,'Std. Error'][2], digits=3)	#st.errror IGL1
  
  results[i,6]<-round(coef(summary(t2))[,'Std. Error'][3], digits=3)	#st.error LAWSL1
  
  results[i,4]<-round(anova(t2)[1,5], digits=2)				#p-value IGL1
  
  results[i,7]<-round(anova(t2)[2,5], digits=2)				#p-value LAWSL1
  
  results[i,8]<-round((sum(interest.groups, na.rm=T)/17),digits=0)	#sumIG
  
  results[i,9]<-sum(laws, na.rm=T)				#sumLAWS
  
}


results<-as.data.frame(results)
colnames(results)<-c('policy.area.','INTG.L1','st.error','p-v','LAWS.L1','st.error2','p-v2','mean.INTG','sum.LAWS')

###Write the table of results
write.csv(results, './results/year/intgroupsONlawsGENERAL.csv')


###Prepare the dotplots
results$policy.area<-recode(results$policy.area., "'03'='Agriculture';'04'='Fisheries';'05'='Social policy';'07'='Transport';'09'='Taxation';'11'='External';'12'='Energy';'13'='Industry';'14'='Regional policy';'15'='Environment';'16'='Sci,edu,culture';'17'='Economic law';'18'='CFSP';'19'='Justice';'10'='EMU'")

results$INTG.L1<-as.numeric(as.character(results$INTG.L1))
results$se<-as.numeric(as.character(results$st.error))
results$lower<-results$INTG.L1-results$se*1.96
results$upper<-results$INTG.L1+results$se*1.96

results$policy.area <- reorder(results$policy.area, results$INTG.L1)

plot1 <- ggplot(results, aes(INTG.L1, policy.area)) + geom_point(size = 3.5) + ylab("")+xlab('Regression coefficient and 95% confidence intervals for the effect of the\n(lagged) number of newly registered interest groups on the volume of new legislation')
plot2<-plot1 + geom_vline(aes(xintercept = 0), linetype = 2) + geom_segment(aes(x=lower, xend=upper, yend=policy.area))

png(file="./results/year/intgroupsONlawsGENERAL.png",width=620,height=540)
plot2
dev.off()

